@@ -11,9 +11,10 @@ sys.path.append(f'{os.path.dirname(os.path.dirname(os.path.abspath(__file__)))}/
 try:
     import sentry_sdk
     sentry_sdk.init(
-        dsn="https://d6d53bb0121041dd97f59e29051a1781@errors-eval.kde.org/13",
+        dsn="https://d6d53bb0121041dd97f59e29051a1781@crash-reports.kde.org/13",
         traces_sample_rate=1.0,
         release="drkonqi@" + os.getenv('DRKONQI_VERSION'),
+        dist=os.getenv('DRKONQI_DISTRIBUTION'),
         ignore_errors=[KeyboardInterrupt],
     )
 except ImportError:
@@ -34,7 +35,6 @@ import binascii
 import platform
 import multiprocessing
 from pathlib import Path
-from pygdbmi import gdbmiparser
 import psutil
 
 class UnexpectedMappingException(Exception):
@@ -107,6 +107,7 @@ class SentryQMLThread:
 
         payload = self.payload
 
+        from pygdbmi import gdbmiparser
         result = gdbmiparser.parse_response("*stopped," + payload)
         frames = result['payload']['frame']
         print(frames)
@@ -240,7 +241,7 @@ class LockReason:
         match func:
             case 'QtLinuxFutex::_q_futex':
                 return LockReason(frame, 8, 'QtLinuxFutex')
-            case '___pthread_cond_wait':
+            case ('___pthread_cond_wait', 'pthread_cond_wait'):
                 return LockReason(frame, 2, 'pthread_cond_wait')
             case 'QWaitCondition::wait':
                 return LockReason(frame, 2, 'QWaitCondition')
@@ -253,6 +254,7 @@ class SentryTrace:
         self.is_crashed = is_crashed
         self.lock_reasons = {}
         self.was_main_thread = False
+        self.crashed = self.is_crashed # different from is_crashed (=input) this indicates if we stumbled over the kcrash handler
 
     def to_dict(self):
         frames = [ SentryFrame(frame) for frame in gdb.FrameIterator.FrameIterator(self.frame) ]
@@ -271,6 +273,7 @@ class SentryTrace:
                     self.lock_reasons[address] = r
                 if frame.function().startswith('KCrash::defaultCrashHandler'):
                     kcrash_index = index
+                    self.crashed = True
                 if frame.function().startswith('QCoreApplication::exec'):
                     self.was_main_thread = True
             if frame.type() == gdb.SIGTRAMP_FRAME:
@@ -300,7 +303,8 @@ class SentryThread:
             'stacktrace': trace.to_dict(),
             'id': self.thread.ptid[1],
             'name': self.thread.name,
-            'crashed': self.is_crashed,
+            'current': self.is_crashed,
+            'crashed': trace.crashed, # side effect
             'main': trace.was_main_thread, # side effect
             'held_locks': trace.lock_reasons, # side effect
         }
@@ -326,7 +330,7 @@ class SentryThread:
                     case 8:
                         state = 'Blocked'
                 break
-        payload['state'] = (state or 'Runnable')
+        payload['state'] = state
         return payload
 
 class SentryImage:
@@ -498,6 +502,14 @@ class SentryImages:
         return ret
 
 class SentryEvent:
+    def cpu_model(self):
+        with open("/proc/cpuinfo") as f:
+            for line in f.readlines():
+                key, value = line.split(':', 2)
+                if key.strip() == 'model name':
+                    return value.strip()
+        return None
+
     def make(self, program, crash_thread):
         crash_signal = int(os.getenv('DRKONQI_SIGNAL'))
         vm = psutil.virtual_memory()
@@ -536,6 +548,7 @@ class SentryEvent:
             'contexts': { # https://develop.sentry.dev/sdk/event-payloads/contexts/
                 'device': {
                     'name': base_data['Hostname'],
+                    'model': self.cpu_model(),
                     'family': base_data['Chassis'],
                     'simulator': base_data['Virtualization'],
                     'arch': platform.machine(),
@@ -648,6 +661,7 @@ def print_qml_frame(frame):
     print("level={level} func={func} at={file}:{line}".format(**data) )
 
 def print_qml_frames(payload):
+    from pygdbmi import gdbmiparser
     response = gdbmiparser.parse_response("*stopped," + payload)
     frames = response['payload']['frame']
     if type(frames) is dict: # single frames traces aren't arrays to make it more fun -.-
@@ -664,6 +678,12 @@ def print_qml_trace():
         print('Cannot QML trace cores :(')
         return
 
+    try:
+        from pygdbmi import gdbmiparser
+    except ImportError:
+        print('Cannot QML trace cores because pygdbmi is missing :(')
+        return
+
     # should we iterate the inferiors? Probably makes no diff for 99% of apps.
     for thread in gdb.selected_inferior().threads():
         if not thread.is_valid():
